==> downloads.html?file=gigkalender_v1.2.80_040.zip: gigkalender/frontend/example_full.php <==
<?php header("content-type: text/html; charset=utf-8"); ?>
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8">
    <link rel="stylesheet" href="example_formate.css" />
    <link rel="alternate" type="application/atom+xml" title="Atom" href="gigkalender/news/news.atom" />
    <link rel="alternate" type="application/rss+xml" title="RSS" href="gigkalender/news/news.rss" />
    <title>Example …</title>
    <style>
      nav {
        margin-bottom: 1em; }
      ul {
        list-style-type: none;
        margin: 0;
        padding: 0;
        overflow: hidden;
        background-color: #333; }
      li {
        float: left; }
      li a {
        display: block;
        color: white;
        text-align: center;
        padding: 14px 16px;
        text-decoration: none; }
      li a:hover:not(.active) {
        background-color: #111; }
      .active {
        background-color: #4CAF50; }
      .column {
        float: left; }
      .left {
        width: 13%; }
      .right {
        width: 87%; }
    </style>
  </head>
  <body>
    <header><h1>GigKalender - Example for a website</h1></header>
    <nav>
      <ul>
        <li><a href="example_full.php?page=news">News</a></li>
        <li><a href="example_full.php?page=calendar">Calendar</a></li>
        <li><a href="example_full.php?page=archive">Archive</a></li>
        <li><a href="example_full.php?page=gallery">Gallery</a></li>
        <li><a href="example_full.php?page=guestbook">Guestbook</a></li>
      </ul>
    </nav>
    <div class="column left">
      <?php
      include ("../calendar/current-month.php");
      //include ("../guestbook/guestbook_form.php");
      ?>
    </div>
    <div class="column right">
    <?php
      switch ($_GET['page']) {
        case 'calendar': include ("../calendar/calendar.php"); break;
        case 'archive': include ("../calendar/calendar_past.php"); break;
        case 'guestbook': include ("../guestbook/guestbook.php"); break;
        case 'news': include ("../news/news.php"); break;
        case 'gallery': include ("../gallery/gallery.php"); break;
      } ?>
    </div>
  </body>
</html>

==> downloads.html?file=gigkalender_v1.2.81_005.zip: gigkalender/frontend/example_full.php <==
<?php header("content-type: text/html; charset=utf-8"); ?>
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8">
    <link rel="stylesheet" href="example_formate.css" />
    <link rel="alternate" type="application/atom+xml" title="Atom" href="gigkalender/news/news.atom" />
    <link rel="alternate" type="application/rss+xml" title="RSS" href="gigkalender/news/news.rss" />
    <title>Example …</title>
    <style>
      nav {
        margin-bottom: 1em; }
      ul {
        list-style-type: none;
        margin: 0;
        padding: 0;
        overflow: hidden;
        background-color: #333; }
      li {
        float: left; }
      li a {
        display: block;
        color: white;
        text-align: center;
        padding: 14px 16px;
        text-decoration: none; }
      li a:hover:not(.active) {
        background-color: #111; }
      .active {
        background-color: #4CAF50; }
      .column {
        float: left; }
      .left {
        width: 13%; }
      .right {
        width: 87%; }
    </style>
  </head>
  <body>
    <header><h1>GigKalender - Example for a website</h1></header>
    <nav>
      <ul>
        <li><a href="example_full.php?page=news">News</a></li>
        <li><a href="example_full.php?page=calendar">Calendar</a></li>
        <li><a href="example_full.php?page=archive">Archive</a></li>
        <li><a href="example_full.php?page=gallery">Gallery</a></li>
        <li><a href="example_full.php?page=guestbook">Guestbook</a></li>
        <li><a href="example_full.php?page=contact">Contact</a></li>
      </ul>
    </nav>
    <div class="column left">
      <?php
      include ("../calendar/current-month.php");
      ?>
    </div>
    <div class="column right">
    <?php
      switch (@$_GET['page']) {
        case 'calendar': include("../calendar/calendar.php"); break;
        case 'archive': include("../calendar/calendar_past.php"); break;
        case 'guestbook': include("../guestbook/guestbook.php"); break;
        case 'news': include("../news/news.php"); break;
        case 'gallery': include("../gallery/gallery.php"); break;
        case 'contact': include("../contact-form/contact-form.php"); break;
        default: include("../news/news.php"); break;
      } ?>
    </div>
  </body>
</html>
